``eradiate``
============

.. automodule:: eradiate

.. py:currentmodule:: eradiate

Configuration
-------------

.. autodata:: config
   :annotation:

Mode management
---------------

.. autodata:: mode
   :annotation:

.. autodata:: modes
   :annotation:

.. autodata:: set_mode
   :annotation:

.. autodata:: supported_mode
   :annotation:

.. autodata:: unsupported_mode
   :annotation:

.. autodata:: Mode
   :annotation:

.. autodata:: SpectralMode
   :annotation:

.. autodata:: MitsubaBackend
   :annotation:

.. autodata:: MitsubaColorMode
   :annotation:

Unit management
---------------

.. autodata:: unit_registry
   :annotation:

.. autodata:: unit_context_config
   :annotation:

.. autodata:: unit_context_kernel
   :annotation:

Metadata
--------

.. autodata:: __version__
   :annotation:

Convenience aliases
-------------------

.. autodata:: run
   :annotation:

.. autodata:: traverse
   :annotation:
